import { Injectable, Logger } from '@nestjs/common';
import { DeviceStatusFirebaseService } from '@app/common/firebase/devices-status/services/devices-status.service';

@Injectable()
export class SosHandlerService {
  private readonly logger = new Logger(SosHandlerService.name);

  constructor(
    private readonly deviceStatusFirebaseService: DeviceStatusFirebaseService,
  ) {}

  isSosTriggered(status: any): boolean {
    return (
      Array.isArray(status) &&
      status.some((item) => item.code === 'sos' && item.value === 'sos')
    );
  }

  async handleSosEventFirebase(device: any, logData: any): Promise<void> {
    const sosTrueStatus = [{ code: 'sos', value: true }];
    const sosFalseStatus = [{ code: 'sos', value: false }];

    try {
      // ✅ Send true status
      await this.deviceStatusFirebaseService.addDeviceStatusToFirebase({
        deviceTuyaUuid: device.deviceTuyaUuid,
        status: sosTrueStatus,
        log: logData,
        device,
      });

      await this.deviceStatusFirebaseService.addBatchDeviceStatusToOurDb([
        {
          deviceTuyaUuid: device.deviceTuyaUuid,
          status: sosTrueStatus,
          log: logData,
          device,
        },
      ]);

      // ✅ Schedule false status
      setTimeout(async () => {
        try {
          await this.deviceStatusFirebaseService.addDeviceStatusToFirebase({
            deviceTuyaUuid: device.deviceTuyaUuid,
            status: sosFalseStatus,
            log: logData,
            device,
          });

          await this.deviceStatusFirebaseService.addBatchDeviceStatusToOurDb([
            {
              deviceTuyaUuid: device.deviceTuyaUuid,
              status: sosFalseStatus,
              log: logData,
              device,
            },
          ]);
        } catch (err) {
          this.logger.error('Failed to send SOS false value', err);
        }
      }, 2000);
    } catch (err) {
      this.logger.error('Failed to send SOS true value', err);
    }
  }
}
