import { Controller, Get, Param, UseGuards } from '@nestjs/common';
import { ApiTags, ApiOperation, ApiBearerAuth } from '@nestjs/swagger';
import { ControllerRoute } from '@app/common/constants/controller-route';
import { EnableDisableStatusEnum } from '@app/common/constants/days.enum';
import { PermissionService } from '../services';
import { JwtAuthGuard } from '@app/common/guards/jwt.auth.guard';

@ApiTags('Permission Module')
@Controller({
  version: EnableDisableStatusEnum.ENABLED,
  path: ControllerRoute.PERMISSION.ROUTE,
})
export class PermissionController {
  constructor(private readonly permissionService: PermissionService) {}
  @ApiBearerAuth()
  @UseGuards(JwtAuthGuard)
  @Get(':roleUuid')
  @ApiOperation({
    summary: ControllerRoute.PERMISSION.ACTIONS.GET_PERMISSION_BY_ROLE_SUMMARY,
    description:
      ControllerRoute.PERMISSION.ACTIONS.GET_PERMISSION_BY_ROLE_DESCRIPTION,
  })
  async getPermissionsByRole(@Param('roleUuid') roleUuid: string) {
    return await this.permissionService.getPermissionsByRole(roleUuid);
  }
}
