import { ControllerRoute } from '@app/common/constants/controller-route';
import {
  Controller,
  Delete,
  Get,
  Param,
  Post,
  UseGuards,
} from '@nestjs/common';
import { ApiBearerAuth, ApiOperation, ApiTags } from '@nestjs/swagger';
import { DeviceSubSpaceParam, GetSubSpaceParam } from '../../dtos';
import { SubspaceDeviceService } from 'src/space/services';
import { BaseResponseDto } from '@app/common/dto/base.response.dto';
import { PermissionsGuard } from 'src/guards/permissions.guard';
import { Permissions } from 'src/decorators/permissions.decorator';

@ApiTags('Space Module')
@Controller({
  version: '1',
  path: ControllerRoute.SUBSPACE_DEVICE.ROUTE,
})
export class SubSpaceDeviceController {
  constructor(private readonly subspaceDeviceService: SubspaceDeviceService) {}

  @ApiBearerAuth()
  @UseGuards(PermissionsGuard)
  @Permissions('SUBSPACE_DEVICE_VIEW_DEVICE_IN_SUBSPACE')
  @ApiOperation({
    summary:
      ControllerRoute.SUBSPACE_DEVICE.ACTIONS.LIST_SUBSPACE_DEVICE_SUMMARY,
    description:
      ControllerRoute.SUBSPACE_DEVICE.ACTIONS.LIST_SUBSPACE_DEVICE_DESCRIPTION,
  })
  @Get()
  async listDevicesInSubspace(
    @Param() params: GetSubSpaceParam,
  ): Promise<BaseResponseDto> {
    return await this.subspaceDeviceService.listDevicesInSubspace(params);
  }

  @ApiBearerAuth()
  @UseGuards(PermissionsGuard)
  @Permissions('SUBSPACE_ASSIGN_DEVICE_TO_SUBSPACE')
  @ApiOperation({
    summary:
      ControllerRoute.SUBSPACE_DEVICE.ACTIONS.ASSOCIATE_SUBSPACE_DEVICE_SUMMARY,
    description:
      ControllerRoute.SUBSPACE_DEVICE.ACTIONS
        .ASSOCIATE_SUBSPACE_DEVICE_DESCRIPTION,
  })
  @Post('/:deviceUuid')
  async associateDeviceToSubspace(
    @Param() params: DeviceSubSpaceParam,
  ): Promise<BaseResponseDto> {
    return await this.subspaceDeviceService.associateDeviceToSubspace(params);
  }

  @ApiBearerAuth()
  @UseGuards(PermissionsGuard)
  @Permissions('SUBSPACE_DELETE_DEVICE_FROM_SUBSPACE')
  @ApiOperation({
    summary:
      ControllerRoute.SUBSPACE_DEVICE.ACTIONS
        .DISASSOCIATE_SUBSPACE_DEVICE_SUMMARY,
    description:
      ControllerRoute.SUBSPACE_DEVICE.ACTIONS
        .DISASSOCIATE_SUBSPACE_DEVICE_DESCRIPTION,
  })
  @Delete('/:deviceUuid')
  async disassociateDeviceFromSubspace(
    @Param() params: DeviceSubSpaceParam,
  ): Promise<BaseResponseDto> {
    return await this.subspaceDeviceService.disassociateDeviceFromSubspace(
      params,
    );
  }
}
