import { VisitorPasswordService } from '../services/visitor-password.service';
import { Body, Controller, Post, UseGuards, Req, Get } from '@nestjs/common';
import { ApiTags, ApiBearerAuth, ApiOperation } from '@nestjs/swagger';
import { AddDoorLockTemporaryPasswordDto } from '../dtos/temp-pass.dto';
import { EnableDisableStatusEnum } from '@app/common/constants/days.enum';
import { ControllerRoute } from '@app/common/constants/controller-route';
import { PermissionsGuard } from 'src/guards/permissions.guard';
import { Permissions } from 'src/decorators/permissions.decorator';

@ApiTags('Visitor Password Module')
@Controller({
  version: EnableDisableStatusEnum.ENABLED,
  path: ControllerRoute.VISITOR_PASSWORD.ROUTE,
})
export class VisitorPasswordController {
  constructor(
    private readonly visitorPasswordService: VisitorPasswordService,
  ) {}

  @ApiBearerAuth()
  @UseGuards(PermissionsGuard)
  @Permissions('VISITOR_PASSWORD_ADD')
  @Post()
  @ApiOperation({
    summary:
      ControllerRoute.VISITOR_PASSWORD.ACTIONS.ADD_VISITOR_PASSWORD_SUMMARY,
    description:
      ControllerRoute.VISITOR_PASSWORD.ACTIONS.ADD_VISITOR_PASSWORD_DESCRIPTION,
  })
  async addTemporaryPassword(
    @Body() addDoorLockTemporaryPasswordDto: AddDoorLockTemporaryPasswordDto,
    @Req() req: any,
  ) {
    const userUuid = req.user.uuid;
    const projectUuid = req.user.project.uuid;
    return await this.visitorPasswordService.handleTemporaryPassword(
      addDoorLockTemporaryPasswordDto,
      userUuid,
      projectUuid,
    );
  }
  @ApiBearerAuth()
  @UseGuards(PermissionsGuard)
  @Permissions('VISITOR_PASSWORD_ADD')
  @Get()
  @ApiOperation({
    summary:
      ControllerRoute.VISITOR_PASSWORD.ACTIONS.GET_VISITOR_PASSWORD_SUMMARY,
    description:
      ControllerRoute.VISITOR_PASSWORD.ACTIONS.GET_VISITOR_PASSWORD_DESCRIPTION,
  })
  async GetVisitorPassword(@Req() req: any) {
    const projectUuid = req.user.project.uuid;
    return await this.visitorPasswordService.getPasswords(projectUuid);
  }
}
